==> icefaces-mobi-4.0.0.jar: META-INF/resources/org.icefaces.component.util/component.c.js <==
Function.prototype.bind||(Function.prototype.bind=function(a){if("function"!==typeof this)throw new TypeError("Function.prototype.bind - what is trying to be bound is not callable");var b=Array.prototype.slice.call(arguments,1),c=this,d=function(){},e=function(){return c.apply(this instanceof d&&a?this:a,b.concat(Array.prototype.slice.call(arguments)))};d.prototype=this.prototype;e.prototype=new d;return e});
"filter"in Array.prototype||(Array.prototype.filter=function(a,b){for(var c=[],d,e=0,f=this.length;e<f;e++)e in this&&a.call(b,d=this[e],e,this)&&c.push(d);return c});"map"in Array.prototype||(Array.prototype.map=function(a,b){for(var c=Array(this.length),d=0,e=this.length;d<e;d++)d in this&&(c[d]=a.call(b,this[d],d,this));return c});
"indexOf"in Array.prototype||(Array.prototype.indexOf=function(a,b){void 0===b&&(b=0);0>b&&(b+=this.length);0>b&&(b=0);for(var c=this.length;b<c;b++)if(b in this&&this[b]===a)return b;return-1});"lastIndexOf"in Array.prototype||(Array.prototype.lastIndexOf=function(a,b){void 0===b&&(b=this.length-1);0>b&&(b+=this.length);b>this.length-1&&(b=this.length-1);for(b++;0<b--;)if(b in this&&this[b]===a)return b;return-1});
"forEach"in Array.prototype||(Array.prototype.forEach=function(a,b){for(var c=0,d=this.length;c<d;c++)c in this&&a.call(b,this[c],c,this)});window.ice||(window.ice={});window.ice.mobi||(window.ice.mobi={});window.mobi||(window.mobi={});window.ice.mobi.impl||(window.ice.mobi.impl={});window.console||(console={},ice.logInContainer?console.log=ice.logInContainer:log=function(){});ice.mobi.escapeJsfId=function(a){return a.replace(/:/g,"\\:")};
ice.mobi.windowHeight=function(){return window.innerHeight||document.documentElement.clientHeight};ice.mobi.addListener=function(a,b,c){a.addEventListener?a.addEventListener(b,c,!1):a.attachEvent?a.attachEvent("on"+b,c):ice.log.debug(ice.log,"WARNING:- this browser does not support addEventListener or attachEvent")};ice.mobi.isNumber=function(a){return!isNaN(parseFloat(a))&&isFinite(a)};
ice.mobi.removeListener=function(a,b,c){a.addEventListener?a.removeEventListener(b,c,!1):a.attachEvent?a.detachEvent("on"+b,c):ice.log.debug(ice.log,"WARNING cannot remove listener for event="+b+" node="+a)};ice.mobi.matches=function(a,b){var c=a.webkitMatchesSelector||a.msMatchesSelector||a.mozMatchesSelector;return c&&c.bind?c.bind(a)(b):-1<Array.prototype.indexOf.call(document.querySelectorAll(b),a)};
ice.mobi.panelCenter=function(a,b){var c=document.getElementById(a),d=b.containerElem||null;if(c){var e=document.getElementById(d),f=b.width||c.offsetWidth,g="",k=b.height||c.offsetHeight;b.width&&(g+=" width: "+(f+"px")+";");b.height&&(g+=" height: "+(k+"px")+";");e?(d=e.offsetWidth,e=e.offsetHeight):(d=mobi._windowWidth(),e=mobi._windowHeight());var h=document.body.scrollTop;0==h&&(h=document.documentElement.scrollTop);0<e?(h=h+(e/2-k/2)+"px",g=0<e-k?g+" position: absolute;"+(" top: "+h+";"):g+
" position: absolute;",g+=" left:"+(d/2-f/2+"px")+";",b.style&&(g+=b.style),c.setAttribute("style",g)):ice.log.debug(ice.log," Containing div or window has no height to autocenter popup of id="+a)}else console.log("Element Not Found id="+a)};
mobi.panelAutoCenter=function(a){var b=mobi._windowWidth(),c=mobi._windowHeight(),d=document.body.scrollTop;0==d&&(d=document.documentElement.scrollTop);if(0<c&&(a=document.getElementById(a))){var e=a.offsetHeight,f=a.offsetWidth;0<c-e?(a.style.position="absolute",a.style.top=d+(c/2-e/2)+"px"):(a.style.position="absolute",a.style.top=0);a.style.left=b/2-f/2+"px"}};
mobi._windowHeight=function(){var a=0;"number"==typeof window.innerHeight?a=window.innerHeight:document.documentElement&&document.documentElement.clientHeight?a=document.documentElement.clientHeight:document.body&&document.body.clientHeight&&(a=document.body.clientHeight);return a};
mobi._windowWidth=function(){var a=0;"number"==typeof window.innerWidth?a=window.innerWidth:document.documentElement&&document.documentElement.clientWidth?a=document.documentElement.clientWidth:document.body&&document.body.clientWidth&&(a=document.body.clientWidth);return a};ice.mobi.formOf=function(a){for(;null!=a;){if("form"==a.nodeName.toLowerCase())return a;a=a.parentNode}};
ice.mobi.unpackDeviceResponse=function(a){var b={};a=a.split("&");for(var c=a.length,d=0;d<c;d++){var e=a[d].indexOf("="),f=unescape(a[d].substring(0,e)),e=unescape(a[d].substring(e+1));"!"===f.substring(0,1)?b[f.substring(1)]=e:(b.name=f,b.value=e)}return b};
ice.mobi.setInput=function(a,b,c,d){var e=b+"-hid",f=document.getElementById(e);if(f)f.setAttribute("value",c);else if(a=document.getElementById(a))f=document.createElement("input"),f.setAttribute("type","hidden"),f.setAttribute("id",e),f.setAttribute("name",b),f.setAttribute("value",c),d&&f.setAttribute("data-type",d),a.parentNode.insertBefore(f,a)};ice.mobi.getStyleSheet=function(a){return Array.prototype.filter.call(document.styleSheets,function(b){return b.title==a})[0]};
ice.mobi.addStyleSheet=function(a,b){var c=document.createElement("style");c.type="text/css";c.rel="stylesheet";c.title=a;document.querySelectorAll(b||"head")[0].appendChild(c);return ice.mobi.getStyleSheet(a)};ice.mobi.addListener(document,"touchstart",function(){});
(function(){ice.mobi.sizePagePanelsToViewPort=function(){if(!(-1<document.documentElement.className.indexOf("desktop")))for(var a=document.querySelectorAll(".mobi-pagePanel"),b=0;b<a.length;){var c=0<a[b].querySelectorAll(".mobi-pagePanel-header").length,d=0<a[b].querySelectorAll(".mobi-pagePanel-header.ui-header-fixed").length,e=0<a[b].querySelectorAll(".mobi-pagePanel-footer").length,f=0<a[b].querySelectorAll(".mobi-pagePanel-footer.ui-footer-fixed").length,g=window.innerHeight;c&&!d&&(g-=40);e&&
!f&&(g-=40);if(c=a[b].querySelector(".mobi-pagePanel-body"))c.style.minHeight=""+g+"px";b++}};window.innerHeight&&(window.addEventListener("load",ice.mobi.sizePagePanelsToViewPort),ice.mobi.addListener(window,"orientationchange",ice.mobi.sizePagePanelsToViewPort),ice.mobi.addListener(window,"resize",ice.mobi.sizePagePanelsToViewPort))})();ice.mobi.fallback={};
ice.mobi.fallback.setupLaunchFailed=function(a,b){bridgeit.launchFailed=function(){document.getElementById(a).style.display="none";document.getElementById(b).style.display="inline";bridgeit.launchFailed=function(){}};var c=setTimeout(function(){clearTimeout(c);bridgeit.launchFailed=function(){}},3500)};
ice.mobi.button=function(a){var b=this;this.buttonElement=document.getElementById(a);this.addClass("ui-button ui-widget ui-state-default ui-corner-all ui-button-text-only");this.buttonElement.setAttribute("role","button");this.buttonElement.firstChild.className="ui-button-text";this.buttonElement.disabled?this.addClass("ui-state-disabled"):(this.buttonElement.onmouseenter=function(a){b.addClass("ui-state-hover")},this.buttonElement.onmouseleave=function(a){b.removeClass("ui-state-hover");b.removeClass("ui-state-active")},
this.buttonElement.onfocus=function(a){b.addClass("ui-state-focus")},this.buttonElement.onblur=function(a){b.removeClass("ui-state-focus")},this.buttonElement.onmousedown=function(a){b.addClass("ui-state-active")},this.buttonElement.onmouseup=function(a){b.removeClass("ui-state-active")},this.buttonElement.onkeydown=function(a){32!=a.keyCode&&13!=a.keyCode||b.addClass("ui-state-active")},this.buttonElement.onkeyup=function(a){b.removeClass("ui-state-active")})};
ice.mobi.button.prototype.addClass=function(a){this.buttonElement.className+=" "+a};ice.mobi.button.prototype.removeClass=function(a){this.buttonElement.className=this.buttonElement.className.replace(RegExp("(?:^|\\s)"+a+"(?!\\S)","g"),"")};

==> icefaces-mobi-4.3.0.jar: META-INF/resources/org.icefaces.component.util/component.c.js <==
Function.prototype.bind||(Function.prototype.bind=function(a){if("function"!==typeof this)throw new TypeError("Function.prototype.bind - what is trying to be bound is not callable");var b=Array.prototype.slice.call(arguments,1),c=this,d=function(){},e=function(){return c.apply(this instanceof d&&a?this:a,b.concat(Array.prototype.slice.call(arguments)))};d.prototype=this.prototype;e.prototype=new d;return e});
"filter"in Array.prototype||(Array.prototype.filter=function(a,b){for(var c=[],d,e=0,f=this.length;e<f;e++)e in this&&a.call(b,d=this[e],e,this)&&c.push(d);return c});"map"in Array.prototype||(Array.prototype.map=function(a,b){for(var c=Array(this.length),d=0,e=this.length;d<e;d++)d in this&&(c[d]=a.call(b,this[d],d,this));return c});
"indexOf"in Array.prototype||(Array.prototype.indexOf=function(a,b){void 0===b&&(b=0);0>b&&(b+=this.length);0>b&&(b=0);for(var c=this.length;b<c;b++)if(b in this&&this[b]===a)return b;return-1});"lastIndexOf"in Array.prototype||(Array.prototype.lastIndexOf=function(a,b){void 0===b&&(b=this.length-1);0>b&&(b+=this.length);b>this.length-1&&(b=this.length-1);for(b++;0<b--;)if(b in this&&this[b]===a)return b;return-1});
"forEach"in Array.prototype||(Array.prototype.forEach=function(a,b){for(var c=0,d=this.length;c<d;c++)c in this&&a.call(b,this[c],c,this)});window.ice||(window.ice={});window.ice.mobi||(window.ice.mobi={});window.mobi||(window.mobi={});window.ice.mobi.impl||(window.ice.mobi.impl={});window.console||(console={},ice.logInContainer?console.log=ice.logInContainer:log=function(){});ice.mobi.escapeJsfId=function(a){return a.replace(/:/g,"\\:")};
ice.mobi.windowHeight=function(){return window.innerHeight||document.documentElement.clientHeight};ice.mobi.addListener=function(a,b,c){a.addEventListener?a.addEventListener(b,c,!1):a.attachEvent?a.attachEvent("on"+b,c):ice.log.debug(ice.log,"WARNING:- this browser does not support addEventListener or attachEvent")};ice.mobi.isNumber=function(a){return!isNaN(parseFloat(a))&&isFinite(a)};
ice.mobi.removeListener=function(a,b,c){a.addEventListener?a.removeEventListener(b,c,!1):a.attachEvent?a.detachEvent("on"+b,c):ice.log.debug(ice.log,"WARNING cannot remove listener for event="+b+" node="+a)};ice.mobi.matches=function(a,b){var c=a.webkitMatchesSelector||a.msMatchesSelector||a.mozMatchesSelector;return c&&c.bind?c.bind(a)(b):-1<Array.prototype.indexOf.call(document.querySelectorAll(b),a)};
ice.mobi.panelCenter=function(a,b){var c=document.getElementById(a),d=b.containerElem||null;if(c){var e=document.getElementById(d),f=b.width||c.offsetWidth,g="",k=b.height||c.offsetHeight;b.width&&(g+=" width: "+(f+"px")+";");b.height&&(g+=" height: "+(k+"px")+";");e?(d=e.offsetWidth,e=e.offsetHeight):(d=mobi._windowWidth(),e=mobi._windowHeight());var h=document.body.scrollTop;0==h&&(h=document.documentElement.scrollTop);0<e?(h=h+(e/2-k/2)+"px",g=0<e-k?g+" position: absolute;"+(" top: "+h+";"):g+
" position: absolute;",g+=" left:"+(d/2-f/2+"px")+";",b.style&&(g+=b.style),c.setAttribute("style",g)):ice.log.debug(ice.log," Containing div or window has no height to autocenter popup of id="+a)}else console.log("Element Not Found id="+a)};
mobi.panelAutoCenter=function(a){var b=mobi._windowWidth(),c=mobi._windowHeight(),d=document.body.scrollTop;0==d&&(d=document.documentElement.scrollTop);if(0<c&&(a=document.getElementById(a))){var e=a.offsetHeight,f=a.offsetWidth;0<c-e?(a.style.position="absolute",a.style.top=d+(c/2-e/2)+"px"):(a.style.position="absolute",a.style.top=0);a.style.left=b/2-f/2+"px"}};
mobi._windowHeight=function(){var a=0;"number"==typeof window.innerHeight?a=window.innerHeight:document.documentElement&&document.documentElement.clientHeight?a=document.documentElement.clientHeight:document.body&&document.body.clientHeight&&(a=document.body.clientHeight);return a};
mobi._windowWidth=function(){var a=0;"number"==typeof window.innerWidth?a=window.innerWidth:document.documentElement&&document.documentElement.clientWidth?a=document.documentElement.clientWidth:document.body&&document.body.clientWidth&&(a=document.body.clientWidth);return a};ice.mobi.formOf=function(a){for(;null!=a;){if("form"==a.nodeName.toLowerCase())return a;a=a.parentNode}};
ice.mobi.unpackDeviceResponse=function(a){var b={};a=a.split("&");for(var c=a.length,d=0;d<c;d++){var e=a[d].indexOf("="),f=unescape(a[d].substring(0,e)),e=unescape(a[d].substring(e+1));"!"===f.substring(0,1)?b[f.substring(1)]=e:(b.name=f,b.value=e)}return b};
ice.mobi.setInput=function(a,b,c,d){var e=b+"-hid",f=document.getElementById(e);if(f)f.setAttribute("value",c);else if(a=document.getElementById(a))f=document.createElement("input"),f.setAttribute("type","hidden"),f.setAttribute("id",e),f.setAttribute("name",b),f.setAttribute("value",c),d&&f.setAttribute("data-type",d),a.parentNode.insertBefore(f,a)};ice.mobi.getStyleSheet=function(a){return Array.prototype.filter.call(document.styleSheets,function(b){return b.title==a})[0]};
ice.mobi.addStyleSheet=function(a,b){var c=document.createElement("style");c.type="text/css";c.rel="stylesheet";c.title=a;document.querySelectorAll(b||"head")[0].appendChild(c);return ice.mobi.getStyleSheet(a)};ice.mobi.addListener(document,"touchstart",function(){});
(function(){ice.mobi.sizePagePanelsToViewPort=function(){console.log("sizePagePanels....");if(!(-1<document.documentElement.className.indexOf("desktop"))){console.log(" not desktop");var a=document.querySelectorAll(".mobi-pagePanel"),b=0;for(console.log(" pagePanels.length="+a.length);b<a.length;){var c=0<a[b].querySelectorAll(".mobi-pagePanel-header").length,d=0<a[b].querySelectorAll(".mobi-pagePanel-header.ui-header-fixed").length,e=0<a[b].querySelectorAll(".mobi-pagePanel-footer").length,f=0<a[b].querySelectorAll(".mobi-pagePanel-footer.ui-footer-fixed").length,
g=window.innerHeight;console.log(" innerHeight="+window.innerHeight+" hasHeader="+c+" hasFixedHeader");c&&!d&&(g-=40);e&&!f&&(g-=40);if(c=a[b].querySelector(".mobi-pagePanel-body"))c.style.minHeight=""+g+"px";b++}}};window.innerHeight&&(window.addEventListener("load",ice.mobi.sizePagePanelsToViewPort),ice.mobi.addListener(window,"orientationchange",ice.mobi.sizePagePanelsToViewPort),ice.mobi.addListener(window,"resize",ice.mobi.sizePagePanelsToViewPort))})();
ice.mobi.button=function(a){var b=this;this.buttonElement=document.getElementById(a);this.addClass("ui-button ui-widget ui-state-default ui-corner-all ui-button-text-only");this.buttonElement.setAttribute("role","button");this.buttonElement.firstChild.className="ui-button-text";this.buttonElement.disabled?this.addClass("ui-state-disabled"):(this.buttonElement.onmouseenter=function(a){b.addClass("ui-state-hover")},this.buttonElement.onmouseleave=function(a){b.removeClass("ui-state-hover");b.removeClass("ui-state-active")},
this.buttonElement.onfocus=function(a){b.addClass("ui-state-focus")},this.buttonElement.onblur=function(a){b.removeClass("ui-state-focus")},this.buttonElement.onmousedown=function(a){b.addClass("ui-state-active")},this.buttonElement.onmouseup=function(a){b.removeClass("ui-state-active")},this.buttonElement.onkeydown=function(a){32!=a.keyCode&&13!=a.keyCode||b.addClass("ui-state-active")},this.buttonElement.onkeyup=function(a){b.removeClass("ui-state-active")})};
ice.mobi.button.prototype.addClass=function(a){this.buttonElement.className+=" "+a};ice.mobi.button.prototype.removeClass=function(a){this.buttonElement.className=this.buttonElement.className.replace(RegExp("(?:^|\\s)"+a+"(?!\\S)","g"),"")};ice.mobi.setupImageButton=function(a){a=document.getElementById(a);a.style.border="0";a.style.backgroundColor="transparent"};
